@@ -22,7 +22,6 @@ class DataMediator:
         `testProportion` (float): Percentage of data from experimental & control sets to holdout. \n
         `controlIDs` (list[str]): List of sample IDs in the control set. \n
         `experimentalIDs` (list[str]): List of sample IDs in the experimental set. \n
-        `externalIDs` (list[str]): List of sample IDs for external validation. \n
         `randomSeed` (int): Seed number to replicate psuedorandom sampling.
 
     [Optional]
@@ -151,7 +150,8 @@ class DataMediator:
         for ID in IDs:
             if ID not in self.dataframe.index:
                 missingIDs.append(ID)
-        print(f"samples missing from feature data: {missingIDs}")
+        if self.verbose:
+            print(f"samples missing from feature data: {missingIDs}")
         return self.dataframe.loc[[ID for ID in IDs if ID in self.dataframe.index]]
 
     def __balance(
